# bgood-widget

> bgood basics widget project

## Build Setup

``` bash
# install dependencies
npm install

# serve with hot reload at localhost:8080
npm run dev

# build for production with minification
npm run build

# build for production and view the bundle analyzer report
npm run build --report

# run unit tests
npm run unit

# run e2e tests
npm run e2e

# run all tests
npm test
```
> 使用规范
``` bash
  1组件命名:驼峰形式，首字母必须大写
  2方法命名：小驼峰式命名法。
   命名规范：前缀应当是名词。(函数的名字前缀为动词，以此区分变量和函数)
      1：事件操作类以handle开头
      2：非事件操作类
          1：查询用get开头（查询列表以List结尾，查询实体信息以Info结尾）
          2：修改用update开头
          3：删除delete开头
          4：过滤以filter开头
          5: 判断以is开头
      注意：方法命名一定要规范，一定要语义化（所谓语义化即通过方法名称就可以知道方法作用）
  3常量全部大写
  4类 & 构造函数
     命名方法：大驼峰式命名法，首字母大写。
     命名规范：前缀为名称。
  5无用代码一律删除，代码一定要格式化整齐（做到整洁易读）
```
> 页面结构规范
``` bash
  1页面结构层次清晰
  一般情况下我们分为头部(header)，内容区(content)，尾部(footer)
  2除特殊情况外，不允许在style里面写样式
  3排版要整齐
```
> 组件使用文档
##table组件
``` bash
#1:使用
import {GridTable} from 'bgood-widget';
<GridTable
         :pageSize="pageSize"
         :onChangePage="handleChangePage"
         :total="vatTotal"
         :obState="ObservableState(vatList)"
         :loading="loading(vatList)"
         :columns="columns"
         selectedColumnName="id"
         :isClear="isClear"
         :onGetSelectedRowId="getSelectedRow"
         :data="getData">

       </GridTable>
props参数说明:
  pageSize:每页显示数据条数
  onChangePage:页面跳转执行数据查询函数
  total:数据总数
  obState:需要监听数据的状态，这里直接把需要监听的数据放入ObservableState函数，返回数据状态对象（包含请求中，请求成功,请求失败，超时，网络未连接等）
  loading:通过监听的数据对象状态来控制loading图层的出现与消失
  columns:列描述数据对象,对应iView
  isClear:是否清理选中行数据，布尔类型，等于true,在执行清理数据的时候需要调用this.handleClearSelected 函数
  onGetSelectedRowId:在选中行数据的时候通过传入此回调函数，可把选中的行数据挂载到this.selectedRowObject数组里面
  data:需要绑定到table里面的数据
```
##ModalBasic 对话框组件
``` bash
#1:使用
import {ModalBasic} from 'bgood-widget';
<ModalBasic :visible="visibleModal"
               :title="titleModal"
               :content="componentContent"
               :width="widthModal"
               :onCancel="handleCloseModal">

   </ModalBasic>
props参数说明:
  visible:布尔类型 true显示，false:隐藏
  title:标题名称 string类型
  content:需要展示的内容，传入组件类型
  width:宽度大小数字或者字符串类型数字
  onCancel:关闭事件，在这里我们提供了this.handleCloseModal这个函数来关闭
```

##breadcrumb面包屑基础组件
``` bash
#1:使用
import {breadcrumb} from 'bgood-widget';
参照iView面包屑组件文档
```

##CrumbWrap面包屑业务组件
``` bash
#1:使用
import {CrumbWrap} from 'bgood-widget';
<CrumbWrap :crumbItem="crumbItem"></CrumbWrap>
const CrumbItem=[
  {name:'行政/法务系统'},
  {name:'品牌批发'},
  {name:'收付款单',href:'/collect-pay'}
]
当你需要做跳转功能，则需要带上href，如果你需要刷新当前页则设置成reload为true,例如{name:'VAT税收管理',href:'/vat',reload:true}
```
##PageBasic分页组件
``` bash
#1:使用

<PageBasic :pageSize="pageSize" :total="total"  :onChangePage="onChangePage"></PageBasic>
props参数说明:
pageSize:每页显示条数
total：总数
onChangePage:页面跳转执行数据查询函数
```

##upload上传组件
``` bash
#1:使用

 <UploadForm action="https://fileupload.sellercube.com/api/upload"
                    :historyList="historyFileList"
                    accept=".doc,.jpeg,.jpg,.xlsx,.xls,.pdf,.png"
                    :maxFileCount="1"
                    refName="upload"
                    v-model="formValidate.filePath"
                    :validate="handleValidate"
                    :onUploadSuccess="handleUploadSuccess"
        >
props参数说明:
refName:组件名称
maxFileCount：最大可上传附件数，默认1
accept:可支持上传文件类型
historyList:已上传到服务器的文件列表
action：上传服务器地址
validate:获取上传组件验证方法，一般情况下我们用不上，可以忽略
onUploadSuccess：文件上传成功回调事件，返回参数列表filePath(数组)，fileName(数组)
```
> 组件通用方法说明
##storeBase
``` bash
 use
 import storeBase from '../../store/mixins/storeBase';
 1:获取store对象指定数据
 getStore(store) {
       return this.$store.state[store];
     }
 2：顶部进度条函数
 pageLoadingBar(state){
       if(state instanceof ObservablePromiseModel){
         if(state.isPending&&!state.isResolved){
             LoadingBar.start();
         }
         else if(state.isResolved){
             LoadingBar.finish();
         }
         else {
             LoadingBar.error();
         }
       }
     },
 3:弹出信息提示方法
 messageAlert(curVal,message,failMessage,funcArray){
       if(failMessage&&failMessage.constructor===Array){
         funcArray=failMessage;
       }
       if(message&&message.constructor===Array){
         funcArray=message;
       }
       if (curVal.isResolved) {
         let result = curVal.data.success;
         if (result) {
           Message.success(message||curVal.data.message);
           this.reduceHandleEven(funcArray);
         }
         else if (result === false) {
           Message.warning(curVal.data.message||failMessage);
         }
       }
     },
```
##tableList
``` bash
    import tableList from 'bgood-widget/lib/utils/mixin/tableList';
    import registerComponent from 'bgood-widget/lib/utils/mixin/registerComponent';

    所有列表页都要通过mixins方式注入tableList，registerComponent这里面包含列表页一些常用方法，常用组件注册等，可以有效的复用代码，并进行维护
```
For detailed explanation on how things work, checkout the [guide](http://vuejs-templates.github.io/webpack/) and [docs for vue-loader](http://vuejs.github.io/vue-loader).
